diff --git a/doc/ov_read.html b/doc/ov_read.html
index 208ef18..f71c60c 100644
--- a/doc/ov_read.html
+++ b/doc/ov_read.html
@@ -25,6 +25,12 @@
    If the passed in buffer is large, <tt>ov_read()</tt> will not fill
    it; the passed in buffer size is treated as a <em>limit</em> and
    not a request.
+
+<p>
+You should ensure that the passed-in buffer is aligned on a 16-bit
+boundary, since it will be filled with an array of signed 16-bit
+values.
+
 <p>
    
 Note that up to this point, the Tremor API could more or less hide the
@@ -76,6 +82,10 @@ functions.</dd>
 <dt>OV_EBADLINK</dt>
   <dd>indicates that an invalid stream section was supplied to
       libvorbisidec, or the requested link is corrupt.</dd>
+<dt>OV_EINVAL</dt>
+  <dd>indicates that one of the parameters was invalid (either the
+file is already opened, or the buffer not aligned on 16-bit
+boundary)</dd>
 <dt>0</dt>
   <dd>indicates EOF</dd>
 <dt><i>n</i></dt>
diff --git a/vorbisfile.c b/vorbisfile.c
index a0967a4..a80bbde 100644
--- a/vorbisfile.c
+++ b/vorbisfile.c
@@ -1806,6 +1806,7 @@ vorbis_comment *ov_comment(OggVorbis_File *vf,int link){
    functions above are aware of this dichotomy).
 
    input values: buffer) a buffer to hold packed PCM data for return
+                         (this should be short-aligned, not char-aligned)
 		 length) the byte length requested to be placed into buffer
 
    return values: <0) error/hole in data (OV_HOLE), partial open (OV_EINVAL)
@@ -1825,6 +1826,9 @@ long ov_read(OggVorbis_File *vf,char *buffer,int bytes_req,int *bitstream){
 
   if(vf->ready_state<OPENED)return(OV_EINVAL);
 
+  /* ensure that the buffer is aligned on a short boundary */
+  if(((unsigned int)buffer)%(sizeof(short))!=0)return(OV_EINVAL);
+
   while(1){
     if(vf->ready_state==INITSET){
       samples=vorbis_synthesis_pcmout(&vf->vd,&pcm);
